@@ -241,23 +241,21 @@ class BackupJob {
         $this->createSiteArchive($sourcePath, $localPath, $user, $domain);
     }
     
-    private function createUserfilesBackup($data, $localPath) {
+    private function createUserfilesBackup($data, &$localPath) {
         $metadata = is_array($data['metadata']) ? $data['metadata'] : json_decode($data['metadata'], true);
         $sourcePath = $metadata['source_path'];
         $user = $data['user'];
 
         // Add .zip extension to localPath if not present
         if (substr($localPath, -4) !== '.zip') {
-            $actualPath = $localPath . '.zip';
+            $localPath = $localPath . '.zip';
             // Update database with actual path including .zip extension
             $stmt = $this->db->prepare("UPDATE backup_history SET local_path = ? WHERE id = ?");
-            $stmt->execute([$actualPath, $data['id']]);
-        } else {
-            $actualPath = $localPath;
+            $stmt->execute([$localPath, $data['id']]);
         }
 
         // Create archive directly to local storage (use zip for better compatibility)
-        $this->createUserfilesArchiveZip($sourcePath, $actualPath, $user);
+        $this->createUserfilesArchiveZip($sourcePath, $localPath, $user);
     }
     
     private function createDatabaseBackup($data, $localPath) {
